"""*pageobject*'s main module"""

__version__ = '0.0.46'

from .page import Page
from .pageobject import PageObject
from .pageobjectlist import PageObjectList
from .select import Select

